@@ -1,4 +1,4 @@
-//! Module containing definitions of inquire's error handling
+//! Definitions of inquire's error handling
 
 use std::io;
 
@@ -7,11 +7,13 @@ use thiserror::Error;
 /// Inquire errors
 #[derive(Error, Debug)]
 pub enum InquireError {
-    /// The input device is not a TTY.
+    /// The input device is not a TTY, which means that enabling raw mode
+    /// on the terminal in order to listen to input events is not possible.
     #[error("The input device is not a TTY")]
     NotTTY,
 
-    /// The input device is not a TTY.
+    /// The given prompt configuration is not valid. A detailed error message
+    /// is contained in the value string.
     #[error("The prompt configuration is invalid: {0}")]
     InvalidConfiguration(String),
 
@@ -19,13 +21,7 @@ pub enum InquireError {
     #[error("IO error: {0}")]
     IO(#[from] io::Error),
 
-    /// Invalid state when processing prompt.
-    /// Created to check edge cases but should not happen.
-    #[error("Invalid state: {0}")]
-    InvalidState(String),
-
-    /// Returned when the user canceled the operation, probably
-    /// by pressing Ctrl+C or ESC.
+    /// The user canceled the operation by pressing Ctrl+C or ESC.
     #[error("Operation was canceled by the user")]
     OperationCanceled,
 }
