@@ -1,15 +1,14 @@
 use crate::{
-    error::{InquireError, InquireResult},
+    error::InquireResult,
     formatter::{BoolFormatter, DEFAULT_BOOL_FORMATTER},
-    input::Input,
-    key::Key,
     parser::{BoolParser, DEFAULT_BOOL_PARSER},
     renderer::Renderer,
     terminal::Terminal,
+    CustomType,
 };
 
-/// Presents a message to the user and asks them for a yes/no confirmation.
-#[derive(Copy, Clone)]
+/// Confirmation prompt, expecting y/n answers and returning a bool value.
+#[derive(Clone)]
 pub struct Confirm<'a> {
     /// Message to be presented to the user.
     pub message: &'a str,
@@ -23,18 +22,21 @@ pub struct Confirm<'a> {
     /// Function that formats the user input and presents it to the user as the final rendering of the prompt.
     pub formatter: BoolFormatter<'a>,
 
-    /// Function that parses the user input and returns the result
+    /// Function that parses the user input and returns the result value.
     pub parser: BoolParser<'a>,
 
     /// Function that formats the default value to be presented to the user
     pub default_value_formatter: BoolFormatter<'a>,
+
+    /// Error message displayed when a value could not be parsed from input.
+    pub error_message: String,
 }
 
 impl<'a> Confirm<'a> {
-    /// Default formatter, [true] maps to "Yes" and [false] maps to "No".
+    /// Default formatter, set to [DEFAULT_BOOL_FORMATTER](crate::formatter::DEFAULT_BOOL_FORMATTER)
     pub const DEFAULT_FORMATTER: BoolFormatter<'a> = DEFAULT_BOOL_FORMATTER;
-    /// Default parser, matches ["y"] and ["yes"] to [true], ["n"] and ["no"]
-    /// to [false], and an [Err] otherwise.
+
+    /// Default input parser.
     pub const DEFAULT_PARSER: BoolParser<'a> = DEFAULT_BOOL_PARSER;
 
     /// Default formatter for default values, mapping [true] to ["Y/n"] and
@@ -44,6 +46,10 @@ impl<'a> Confirm<'a> {
         false => String::from("y/N"),
     };
 
+    /// Default error message displayed when parsing fails.
+    pub const DEFAULT_ERROR_MESSAGE: &'a str =
+        "Invalid answer, try typing 'y' for yes or 'n' for no";
+
     /// Creates a [Confirm] with the provided message and default configuration values.
     pub fn new(message: &'a str) -> Self {
         Self {
@@ -53,6 +59,7 @@ impl<'a> Confirm<'a> {
             formatter: Self::DEFAULT_FORMATTER,
             parser: Self::DEFAULT_PARSER,
             default_value_formatter: Self::DEFAULT_DEFAULT_VALUE_FORMATTER,
+            error_message: String::from(Self::DEFAULT_ERROR_MESSAGE),
         }
     }
 
@@ -68,18 +75,24 @@ impl<'a> Confirm<'a> {
         self
     }
 
-    /// Sets the formatter
+    /// Sets the formatter.
     pub fn with_formatter(mut self, formatter: BoolFormatter<'a>) -> Self {
         self.formatter = formatter;
         self
     }
 
-    /// Sets the parser
+    /// Sets the parser.
     pub fn with_parser(mut self, parser: BoolParser<'a>) -> Self {
         self.parser = parser;
         self
     }
 
+    /// Sets a custom error message displayed when a submission could not be parsed to a value.
+    pub fn with_error_message(mut self, error_message: &'a str) -> Self {
+        self.error_message = String::from(error_message);
+        self
+    }
+
     /// Sets the default value formatter
     pub fn with_default_value_formatter(mut self, formatter: BoolFormatter<'a>) -> Self {
         self.default_value_formatter = formatter;
@@ -87,7 +100,7 @@ impl<'a> Confirm<'a> {
     }
 
     /// Parses the provided behavioral and rendering options and prompts
-    /// the CLI user for input according to them.
+    /// the CLI user for input according to the defined rules.
     pub fn prompt(self) -> InquireResult<bool> {
         let terminal = Terminal::new()?;
         let mut renderer = Renderer::new(terminal)?;
@@ -95,7 +108,7 @@ impl<'a> Confirm<'a> {
     }
 
     pub(in crate) fn prompt_with_renderer(self, renderer: &mut Renderer) -> InquireResult<bool> {
-        ConfirmPrompt::from(self).prompt(renderer)
+        CustomType::from(self).prompt_with_renderer(renderer)
     }
 }
 
@@ -105,96 +118,18 @@ impl<'a> From<&'a str> for Confirm<'a> {
     }
 }
 
-struct ConfirmPrompt<'a> {
-    message: &'a str,
-    error: Option<String>,
-    help_message: Option<&'a str>,
-    default: Option<bool>,
-    input: Input,
-    formatter: BoolFormatter<'a>,
-    parser: BoolParser<'a>,
-    default_value_formatter: BoolFormatter<'a>,
-}
-
-impl<'a> From<Confirm<'a>> for ConfirmPrompt<'a> {
+impl<'a> From<Confirm<'a>> for CustomType<'a, bool> {
     fn from(co: Confirm<'a>) -> Self {
         Self {
             message: co.message,
-            error: None,
-            default: co.default,
+            default: match co.default {
+                Some(val) => Some((val, co.default_value_formatter)),
+                None => None,
+            },
             help_message: co.help_message,
             formatter: co.formatter,
             parser: co.parser,
-            default_value_formatter: co.default_value_formatter,
-            input: Input::new(),
+            error_message: co.error_message,
         }
     }
 }
-
-impl<'a> ConfirmPrompt<'a> {
-    fn on_change(&mut self, key: Key) {
-        self.input.handle_key(key);
-    }
-
-    fn get_final_answer(&self) -> Result<bool, String> {
-        match self.default {
-            Some(val) if self.input.content().is_empty() => return Ok(val),
-            _ => {}
-        }
-
-        (self.parser)(self.input.content())
-    }
-
-    fn render(&mut self, renderer: &mut Renderer) -> InquireResult<()> {
-        let prompt = &self.message;
-
-        renderer.reset_prompt()?;
-
-        if let Some(error_message) = &self.error {
-            renderer.print_error_message(error_message)?;
-        }
-
-        let default_message = self.default.map(self.default_value_formatter);
-
-        renderer.print_prompt_input(&prompt, default_message.as_deref(), &self.input)?;
-
-        if let Some(message) = self.help_message {
-            renderer.print_help(message)?;
-        }
-
-        renderer.flush()?;
-
-        Ok(())
-    }
-
-    fn prompt(mut self, renderer: &mut Renderer) -> InquireResult<bool> {
-        let final_answer: bool;
-
-        loop {
-            self.render(renderer)?;
-
-            let key = renderer.read_key()?;
-
-            match key {
-                Key::Cancel => return Err(InquireError::OperationCanceled),
-                Key::Submit => match self.get_final_answer() {
-                    Ok(answer) => {
-                        final_answer = answer;
-                        break;
-                    }
-                    Err(message) => {
-                        self.error = Some(message);
-                        self.input.clear();
-                    }
-                },
-                key => self.on_change(key),
-            }
-        }
-
-        let formatted = (self.formatter)(final_answer);
-
-        renderer.cleanup(&self.message, &formatted)?;
-
-        Ok(final_answer)
-    }
-}
